==> knative-model-6.3.1-sources.jar: io/fabric8/knative/serving/v1/RouteFluentImpl.java <==
package io.fabric8.knative.serving.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RouteFluentImpl<A extends RouteFluent<A>> extends BaseFluent<A> implements RouteFluent<A>{
  public RouteFluentImpl() {
  }
  public RouteFluentImpl(Route instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private RouteSpecBuilder spec;
  private RouteStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public RouteFluent.MetadataNested<A> withNewMetadata() {
    return new RouteFluentImpl.MetadataNestedImpl();
  }
  public RouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new RouteFluentImpl.MetadataNestedImpl(item);
  }
  public RouteFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public RouteFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public RouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public RouteSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public RouteSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(RouteSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new RouteSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public RouteFluent.SpecNested<A> withNewSpec() {
    return new RouteFluentImpl.SpecNestedImpl();
  }
  public RouteFluent.SpecNested<A> withNewSpecLike(RouteSpec item) {
    return new RouteFluentImpl.SpecNestedImpl(item);
  }
  public RouteFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public RouteFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new RouteSpecBuilder().build());
  }
  public RouteFluent.SpecNested<A> editOrNewSpecLike(RouteSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public RouteStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public RouteStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(RouteStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new RouteStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public RouteFluent.StatusNested<A> withNewStatus() {
    return new RouteFluentImpl.StatusNestedImpl();
  }
  public RouteFluent.StatusNested<A> withNewStatusLike(RouteStatus item) {
    return new RouteFluentImpl.StatusNestedImpl(item);
  }
  public RouteFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public RouteFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new RouteStatusBuilder().build());
  }
  public RouteFluent.StatusNested<A> editOrNewStatusLike(RouteStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RouteFluentImpl that = (RouteFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<RouteFluent.MetadataNested<N>> implements RouteFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) RouteFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends RouteSpecFluentImpl<RouteFluent.SpecNested<N>> implements RouteFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(RouteSpec item) {
      this.builder = new RouteSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new RouteSpecBuilder(this);
    }
    RouteSpecBuilder builder;
    public N and() {
      return (N) RouteFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends RouteStatusFluentImpl<RouteFluent.StatusNested<N>> implements RouteFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(RouteStatus item) {
      this.builder = new RouteStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new RouteStatusBuilder(this);
    }
    RouteStatusBuilder builder;
    public N and() {
      return (N) RouteFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/serving/v1/RouteFluentImpl.java <==
package io.fabric8.knative.serving.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RouteFluentImpl<A extends RouteFluent<A>> extends BaseFluent<A> implements RouteFluent<A>{
  public RouteFluentImpl() {
  }
  public RouteFluentImpl(Route instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private RouteSpecBuilder spec;
  private RouteStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public RouteFluentImpl.MetadataNested<A> withNewMetadata() {
    return new RouteFluentImpl.MetadataNestedImpl();
  }
  public RouteFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new RouteFluentImpl.MetadataNestedImpl(item);
  }
  public RouteFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public RouteFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public RouteFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public RouteSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public RouteSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(RouteSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new RouteSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public RouteFluentImpl.SpecNested<A> withNewSpec() {
    return new RouteFluentImpl.SpecNestedImpl();
  }
  public RouteFluentImpl.SpecNested<A> withNewSpecLike(RouteSpec item) {
    return new RouteFluentImpl.SpecNestedImpl(item);
  }
  public RouteFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public RouteFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new RouteSpecBuilder().build());
  }
  public RouteFluentImpl.SpecNested<A> editOrNewSpecLike(RouteSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public RouteStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public RouteStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(RouteStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new RouteStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public RouteFluentImpl.StatusNested<A> withNewStatus() {
    return new RouteFluentImpl.StatusNestedImpl();
  }
  public RouteFluentImpl.StatusNested<A> withNewStatusLike(RouteStatus item) {
    return new RouteFluentImpl.StatusNestedImpl(item);
  }
  public RouteFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public RouteFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new RouteStatusBuilder().build());
  }
  public RouteFluentImpl.StatusNested<A> editOrNewStatusLike(RouteStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RouteFluentImpl that = (RouteFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<RouteFluentImpl.MetadataNested<N>> implements RouteFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) RouteFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends RouteSpecFluentImpl<RouteFluentImpl.SpecNested<N>> implements RouteFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(RouteSpec item) {
      this.builder = new RouteSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new RouteSpecBuilder(this);
    }
    RouteSpecBuilder builder;
    public N and() {
      return (N) RouteFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends RouteStatusFluentImpl<RouteFluentImpl.StatusNested<N>> implements RouteFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(RouteStatus item) {
      this.builder = new RouteStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new RouteStatusBuilder(this);
    }
    RouteStatusBuilder builder;
    public N and() {
      return (N) RouteFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
